==> bodhi-cli-0.9.5.tgz: package/lib/jobs/lifecycle.js <==
module.exports = function(client, views){

    var fs      = require('fs-extra');
    var path    = require('path');
    var _       = require('lodash');

    var JOB           = 'Job';
    var JOB_RESOURCE  = ['resources', JOB].join('/');

    var utils  = require('./jobUtils');
    var prompt = require('prompt');

    function setup(identifier, options){
        client.get(utils.createResource('JobRegistry', identifier, options), function(err, response, body){
            if(err || response.statusCode !== 200){
                var reason = err ? (err.code || err) : response.statusCode;
                console.log('error %s unable to find the job %s', reason, identifier)
            } else {

                var job = {
                    namespace : client.namespace
                };

                var type = JSON.parse(body)[0];

                job.package         = {
                    name: type.name
                };
                prompt.message      = "JobSetup";
                prompt.delimiter    = "::";

                //Greenify the description
                _.each(_.keys(type.parameters), function greenify(key){
                    if(type.parameters[key].description) {
                        type.parameters[key].description = (type.parameters[key].description.green)
                    }
                });

                var properties = {
                    name: {
                        pattern: /^[a-zA-Z\s\-]+$/,
                        description: 'Provide a name for the job'.green,
                        message: 'Name must be only letters, spaces, or dashes',
                        required: true
                    }
                };

                properties = _.extend(properties, type.parameters);

                prompt.start();

                prompt.get({properties: properties}, function(err, result){

                    if(!result){
                        console.log('Aborting the setup');
                        process.exit(0);
                    }

                    //setup the job
                    job.name = result.name;
                    delete result.name;

                    job.settings = result;
                    job.active   = false;

                    client.post(JOB_RESOURCE, job, views.full);

                });
            }
        })
    };

    //--from <name> --to <name>
    function clone(identifier, options){

        if(!options.to){
            console.log('invalid to name');
            process.exit(1);
        }

        client.get(utils.createResource(JOB, identifier, options), job ,function(err, response, body){
            if(err || response.statusCode !== 200){
                var reason = err ? (err.code || err) : response.statusCode;
                console.log('error %s unable to find the job %s', reason, identifier)
            } else {
                body.auth_token = undefined;
                body.name       = options.to;
                client.post(JOB_RESOURCE, body, views.location);
            }
        });
    }

    function list(){
        client.get(JOB_RESOURCE, views.entity)
    }

    function fetch(id, options){
        client.get(utils.createResource(JOB, id, options), views.entity);
    }

    //fetch and cancel a job
    function clear(id, options, cb){
        //post /jobs/:id/schedule
        client.get(utils.createResource(JOB, id, options), function(err, response, jobs){
            var name, job;
            if(err || response.statusCode !== 200){
                cb(new Error('error finding the job'))
            } else {
                jobs = JSON.parse(jobs);
                if(!jobs || jobs.length !== 1){
                    cb(new Error('unknown job'))
                } else {
                    job  = jobs[0];
                    name = jobs[0].name;
                    if(options.verbose) console.log('Canceling previous job ... %s', name);
                    client.post(['jobs', name, 'cancel'].join('/'), {}, function (err, response, jobs) {
                        if(options.verbose) console.log('Job engine', response.statusCode);
                        cb(err, response, job)
                    });
                }
            }
        });
    }

    function operation(job, options){
        options = options || {};
        job.timing_expression = options.timing;
        job.repeat            = (options.repeat) ? true : false;
        job.active            = true;
        return job;
    }

    function noMod(job, options){
        options = options || {};
        return job;
    }

    function activation(job, options){
        options = options || {};
        job.active = true;
        return job;
    }

    function deactivation(job, options){
        options = options || {};
        job.active = false;
        return job;
    }

    function cancellation(job, options){
        options = options || {};
        delete job.timing_expression;
        delete job.repeat;
        job.active = false;
        return job;
    }

    //-t --timing
    function schedule(id, options, modification){
        //post /jobs/:id/schedule
        clear(id, options, function(err, response, job) {

            if(err){
                console.log(err);
                return;
            }

            //establish the timing ...
            var modifier;
            modification = ((modification) ? modification : '').toLowerCase();


            switch(modification){
                case 'schedule':
                    modifier = operation;
                    break;
                case 'resume':
                    modifier = activation;
                    break;
                default:
                    modifier = noMod;
                    break;
            }

            job = modifier(job, options);

            client.put(['resources', JOB, job.sys_id].join('/'), job, function (err, response, jobs) {
                if(err || response.statusCode !== 204){
                    console.log('update failed');
                } else {
                    client.post(['jobs', job.name, 'schedule'].join('/'), {}, function (err, response, jobs) {
                        if (err) {
                            console.log('unable to schedule the job');
                        } else {
                            console.log(response.statusCode);
                            console.log('scheduled %s job', job.name);
                        }
                    });
                }
            });
        });
    }

    //cancel the job AND remove the timing information
    function run(id, options, modification){
        client.get(utils.createResource(JOB, id, options), function(err, response, jobs){
            var name, job;
            if(err || response.statusCode !== 200){
                cb(new Error('error finding the job'))
            } else {
                jobs = JSON.parse(jobs);
                if(!jobs || jobs.length < 1) {
                    console.log('unknown job');
                } else if (jobs.length > 1){
                    console.log('unambiguous job please use the id ');
                } else {
                    job  = jobs[0];
                    name = jobs[0].name;
                    if(options.verbose) console.log('Running the previous job ... %s', name);
                    client.post(['jobs', name, 'now'].join('/'), {}, function (err, response, jobs) {
                        if(options.verbose) console.log('Job engine', response.statusCode);
                        if(err || response.statusCode >= 400){
                            console.log('unable to run the %s job', name);
                        } else {
                            console.log('job %s submitted', name);
                        }
                    });
                }
            }
        });
    }


    //cancel the job AND remove the timing information
    function cancel(id, options, modification){
        clear(id, options, function(err, response, job) {
            var modifier;
            modification = ((modification) ? modification : '').toLowerCase();
            switch(modification){
                case 'cancel':
                    modifier = cancellation;
                    break;
                case 'pause':
                    modifier = deactivation;
                    break;
                default:
                    modifier = noMod;
                    break;
            }
            job = modifier(job, options);
            client.put(['resources', JOB, job.sys_id].join('/'), job, function (err, response, jobs) {
                if(err || response.statusCode !== 204){
                    console.log('update failed');
                } else {
                    client.post(['jobs', job.name, 'schedule'].join('/'), {}, function (err, response, jobs) {
                        if (err) {
                            console.log('unable to schedule the job');
                        } else {
                            console.log(response.statusCode);
                            console.log('scheduled %s job', job.name);
                        }
                    });
                }
            });
        });
    }

    function destroy(id, options){
        clear(id, options, function(err, response, name) {
            client.delete(utils.createResource(JOB, id, options), function (err, response, jobs) {
                if(err){
                    console.log('destro the job');
                } else {
                    console.log('deleted %s job', name);
                }
            })
        });
        client.delete(utils.createResource(JOB, id, options), views.status);
    }

    return {
        setup     : setup,
        clone     : clone,
        list      : list,
        fetch     : fetch,
        schedule  : schedule,
        run       : run,
        cancel    : cancel,
        remove    : destroy
    }

};

==> bodhi-cli-0.9.13.tgz: package/lib/jobs/lifecycle.js <==
module.exports = function(client, views){

    var fs      = require('fs-extra');
    var path    = require('path');
    var _       = require('lodash');

    var JOB           = 'Job';
    var JOB_RESOURCE  = ['resources', JOB].join('/');

    var utils  = require('./jobUtils');
    var prompt = require('prompt');

    function setup(identifier, options){
        client.get(utils.createResource('JobRegistry', identifier, options), function(err, response, body){
            if(err || response.statusCode !== 200){
                var reason = err ? (err.code || err) : response.statusCode;
                console.log('error %s unable to find the job %s', reason, identifier)
            } else {

                var job = {
                    namespace : client.namespace
                };

                var type = JSON.parse(body)[0];

                job.package         = {
                    name: type.name
                };
                prompt.message      = "JobSetup";
                prompt.delimiter    = "::";

                //Greenify the description
                _.each(_.keys(type.parameters), function greenify(key){
                    if(type.parameters[key].description) {
                        type.parameters[key].description = (type.parameters[key].description.green)
                    }
                });

                var properties = {
                    name: {
                        pattern: /^[a-zA-Z\s\-]+$/,
                        description: 'Provide a name for the job'.green,
                        message: 'Name must be only letters, spaces, or dashes',
                        required: true
                    }
                };

                properties = _.extend(properties, type.parameters);

                prompt.start();

                prompt.get({properties: properties}, function(err, result){

                    if(!result){
                        console.log('Aborting the setup');
                        process.exit(0);
                    }

                    //setup the job
                    job.name = result.name;
                    delete result.name;

                    job.settings = result;
                    job.active   = false;

                    client.post(JOB_RESOURCE, job, views.full);

                });
            }
        })
    };

    //--from <name> --to <name>
    function clone(identifier, options){

        if(!options.to){
            console.log('invalid to name');
            process.exit(1);
        }

        client.get(utils.createResource(JOB, identifier, options), job ,function(err, response, body){
            if(err || response.statusCode !== 200){
                var reason = err ? (err.code || err) : response.statusCode;
                console.log('error %s unable to find the job %s', reason, identifier)
            } else {
                body.auth_token = undefined;
                body.name       = options.to;
                client.post(JOB_RESOURCE, body, views.location);
            }
        });
    }

    function list(){
        client.get(JOB_RESOURCE, views.entity)
    }

    function fetch(id, options){
        client.get(utils.createResource(JOB, id, options), views.entity);
    }

    //fetch and cancel a job
    function clear(id, options, cb){
        //post /jobs/:id/schedule
        client.get(utils.createResource(JOB, id, options), function(err, response, jobs){
            var name, job;
            if(err || response.statusCode !== 200){
                cb(new Error('error finding the job'))
            } else {
                jobs = JSON.parse(jobs);
                if(!jobs || jobs.length !== 1){
                    cb(new Error('unknown job'))
                } else {
                    job  = jobs[0];
                    name = jobs[0].name;
                    if(options.verbose) console.log('Canceling previous job ... %s', name);
                    client.post(['jobs', name, 'cancel'].join('/'), {}, function (err, response, jobs) {
                        if(options.verbose) console.log('Job engine', response.statusCode);
                        cb(err, response, job)
                    });
                }
            }
        });
    }

    function operation(job, options){
        options = options || {};
        job.timing_expression = options.timing;
        job.repeat            = (options.repeat) ? true : false;
        job.active            = true;
        return job;
    }

    function noMod(job, options){
        options = options || {};
        return job;
    }

    function activation(job, options){
        options = options || {};
        job.active = true;
        return job;
    }

    function deactivation(job, options){
        options = options || {};
        job.active = false;
        return job;
    }

    function cancellation(job, options){
        options = options || {};
        delete job.timing_expression;
        delete job.repeat;
        job.active = false;
        return job;
    }

    //-t --timing
    function schedule(id, options, modification){
        //post /jobs/:id/schedule
        clear(id, options, function(err, response, job) {

            if(err){
                console.log(err);
                return;
            }

            client.get(['resources', JOB, job.sys_id].join('/'), function (err, response, job) {

                //establish the timing ...
                job = JSON.parse(job);
                var modifier;

                modification = ((modification) ? modification : '').toLowerCase();

                switch (modification) {
                    case 'schedule':
                        modifier = operation;
                        break;
                    case 'resume':
                        modifier = activation;
                        break;
                    default:
                        modifier = noMod;
                        break;
                }

                job = modifier(job, options);

                client.put(['resources', JOB, job.sys_id].join('/'), job, function (err, response, jobs) {
                    if (err || response.statusCode !== 204) {
                        console.log('update failed');
                    } else {
                        client.post(['jobs', job.name, 'schedule'].join('/'), {}, function (err, response, jobs) {
                            if (err) {
                                console.log('unable to schedule the job');
                            } else {
                                console.log(response.statusCode);
                                console.log('scheduled %s job', job.name);
                            }
                        });
                    }
                });
            })
        });
    }

    //cancel the job AND remove the timing information
    function run(id, options, modification){
        client.get(utils.createResource(JOB, id, options), function(err, response, jobs){
            var name, job;
            if(err || response.statusCode !== 200){
                cb(new Error('error finding the job'))
            } else {
                jobs = JSON.parse(jobs);
                if(!jobs || jobs.length < 1) {
                    console.log('unknown job');
                } else if (jobs.length > 1){
                    console.log('unambiguous job please use the id ');
                } else {
                    job  = jobs[0];
                    name = jobs[0].name;
                    if(options.verbose) console.log('Running the previous job ... %s', name);
                    client.post(['jobs', name, 'now'].join('/'), {}, function (err, response, jobs) {
                        if(options.verbose) console.log('Job engine', response.statusCode);
                        if(err || response.statusCode >= 400){
                            console.log('unable to run the %s job', name);
                        } else {
                            console.log('job %s submitted', name);
                        }
                    });
                }
            }
        });
    }

    //cancel the job AND remove the timing information
    function cancel(id, options, modification){
        clear(id, options, function(err, response, job) {
            var modifier;
            modification = ((modification) ? modification : '').toLowerCase();
            switch(modification){
                case 'cancel':
                    modifier = cancellation;
                    break;
                case 'pause':
                    modifier = deactivation;
                    break;
                default:
                    modifier = noMod;
                    break;
            }
            job = modifier(job, options);
            client.put(['resources', JOB, job.sys_id].join('/'), job, function (err, response, jobs) {
                if(err || response.statusCode !== 204){
                    console.log('update failed');
                } else {
                    console.log('job cancelled')
                }
            });
        });
    }

    //lookup, cancel, delete the job
    function destroy(id, options){
        clear(id, options, function(err, response, job) {
            if(err || response.statusCode !== 204){
                console.log('unable to cancel the job');
            } else {
                console.log('cancelled %s job', job.name || '');
                client.delete(['resources', JOB, job.sys_id].join('/'), function (err, response, jobs) {
                    if (err || response.statusCode !== 204) {
                        console.log('unable to delete the job');
                    } else {
                        console.log('job %s removed', job.name || '');
                    }
                });
            }
        });
    }

    return {
        setup     : setup,
        clone     : clone,
        list      : list,
        fetch     : fetch,
        schedule  : schedule,
        run       : run,
        cancel    : cancel,
        remove    : destroy
    }

};
